@@ -24,6 +24,9 @@ def install_subparser(subparser):
     install_parser.add_argument("--prefix",
                                 help="location of the environment to install into",
                                 default=sys.prefix)
+    install_parser.add_argument("--lab",
+                                help="install lab extension",
+                                action='store_true')
     return subparser
 
 def uninstall_subparser(subparser):
@@ -32,6 +35,9 @@ def uninstall_subparser(subparser):
     uninstall_parser.add_argument("--prefix",
                                   help="location of the environment to uninstall from",
                                   default=sys.prefix)
+    uninstall_parser.add_argument("--lab",
+                                help="uninstall lab extension",
+                                action='store_true')
     return subparser
 
 def bkr2ipynb_subparser(subparser):
